@@ -1,7 +1,6 @@
 from typing import List, Literal, Optional
 
 from .basemodel import Base
-from .user import User
 from .beatmap import Beatmap, Beatmapset
 
 
@@ -30,8 +29,7 @@ class Score(Base):
     created_at: str
     mode: Literal['fruits', 'mania', 'osu', 'taiko']
     mode_int: int
-    user: User
-    beatmap: Beatmap
+    beatmap: Optional[Beatmap]
     beatmapset: Optional[Beatmapset]
 
 
